@@ -115,7 +115,7 @@ Regexp::Common::comment -- provide regexes for comments.
         /$RE{comment}{HTML}/    and  print "Contains an HTML comment\n";
     }
 
-    use Rexexp::Common qw /comment RE_comment_HTML/;
+    use Regexp::Common qw /comment RE_comment_HTML/;
 
     while (<>) {
         $_ =~ RE_comment_HTML() and  print "Contains an HTML comment\n";
@@ -123,10 +123,10 @@ Regexp::Common::comment -- provide regexes for comments.
 
 =head1 DESCRIPTION
 
-Please consult the manual of L<Regex::Common> for a general description
+Please consult the manual of L<Regexp::Common> for a general description
 of the works of this interface.
 
-Do not use this module directly, but load it via I<Regex::Common>.
+Do not use this module directly, but load it via I<Regexp::Common>.
 
 This modules gives you regular expressions for comments in various
 languages.
